/*
 * LCD-Wecker mit grafischem Display (240x128 Pixel) und Controller UC1611s, Scott-Falk Hhn, "sound.h"
 * Frequenztabelle und Notenlisten fr 10 Alarm-Signale
 */

#ifndef SOUND_H_
#define SOUND_H_

#define PRECNT 16   // Timer im Toggle-Mode und Vorteiler = 8

// Frequenztabelle, enthlt 73 Notenwerte im Bereich von C bis c"" als 16-Bit-Werte mit einer Genauigkeit von 0,1Hz

const uint16_t freqdata_array[] PROGMEM =
{
  F_CPU * 10 / PRECNT / 654 - 1,    F_CPU * 10 / PRECNT / 693 - 1,    F_CPU * 10 / PRECNT / 734 - 1,    F_CPU * 10 / PRECNT / 778 - 1,    // C   Cis   D   Dis   (00-03)
  F_CPU * 10 / PRECNT / 824 - 1,    F_CPU * 10 / PRECNT / 873 - 1,    F_CPU * 10 / PRECNT / 925 - 1,    F_CPU * 10 / PRECNT / 980 - 1,    // E  F  Fis  G        (04-07)
  F_CPU * 10 / PRECNT / 1038 - 1,   F_CPU * 10 / PRECNT / 1100 - 1,   F_CPU * 10 / PRECNT / 1165 - 1,   F_CPU * 10 / PRECNT / 1235 - 1,   // Gis   A   Ais   H   (08-11)
  F_CPU * 10 / PRECNT / 1308 - 1,   F_CPU * 10 / PRECNT / 1386 - 1,   F_CPU * 10 / PRECNT / 1468 - 1,   F_CPU * 10 / PRECNT / 1556 - 1,   // c   cis   d   dis   (12-15)
  F_CPU * 10 / PRECNT / 1648 - 1,   F_CPU * 10 / PRECNT / 1746 - 1,   F_CPU * 10 / PRECNT / 1850 - 1,   F_CPU * 10 / PRECNT / 1960 - 1,   // e  f  fis  g        (16-19)
  F_CPU * 10 / PRECNT / 2077 - 1,   F_CPU * 10 / PRECNT / 2200 - 1,   F_CPU * 10 / PRECNT / 2331 - 1,   F_CPU * 10 / PRECNT / 2469 - 1,   // gis   a   ais   h   (20-23)
  F_CPU * 10 / PRECNT / 2616 - 1,   F_CPU * 10 / PRECNT / 2772 - 1,   F_CPU * 10 / PRECNT / 2937 - 1,   F_CPU * 10 / PRECNT / 3111 - 1,   // c'  cis'  d'  dis'  (24-27)
  F_CPU * 10 / PRECNT / 3296 - 1,   F_CPU * 10 / PRECNT / 3492 - 1,   F_CPU * 10 / PRECNT / 3700 - 1,   F_CPU * 10 / PRECNT / 3920 - 1,   // e'  f'  fis'  g'    (28-31)
  F_CPU * 10 / PRECNT / 4153 - 1,   F_CPU * 10 / PRECNT / 4400 - 1,   F_CPU * 10 / PRECNT / 4662 - 1,   F_CPU * 10 / PRECNT / 4939 - 1,   // gis'  a'  ais'  h'  (32-35)
  F_CPU * 10 / PRECNT / 5233 - 1,   F_CPU * 10 / PRECNT / 5544 - 1,   F_CPU * 10 / PRECNT / 5873 - 1,   F_CPU * 10 / PRECNT / 6223 - 1,   // c"  cis"  d"  dis"  (36-39)
  F_CPU * 10 / PRECNT / 6593 - 1,   F_CPU * 10 / PRECNT / 6985 - 1,   F_CPU * 10 / PRECNT / 7400 - 1,   F_CPU * 10 / PRECNT / 7840 - 1,   // e"  f"  fis"  g"    (40-43)
  F_CPU * 10 / PRECNT / 8306 - 1,   F_CPU * 10 / PRECNT / 8800 - 1,   F_CPU * 10 / PRECNT / 9323 - 1,   F_CPU * 10 / PRECNT / 9878 - 1,   // gis"  a"  ais"  h"  (44-47)
  F_CPU * 10 / PRECNT / 10465 - 1,  F_CPU * 10 / PRECNT / 11087 - 1,  F_CPU * 10 / PRECNT / 11747 - 1,  F_CPU * 10 / PRECNT / 12445 - 1,  // c"  cis"  d"  dis"  (48-51)
  F_CPU * 10 / PRECNT / 13185 - 1,  F_CPU * 10 / PRECNT / 13969 - 1,  F_CPU * 10 / PRECNT / 14800 - 1,  F_CPU * 10 / PRECNT / 15680 - 1,  // e"  f"  fis"  g"    (52-55)
  F_CPU * 10 / PRECNT / 16612 - 1,  F_CPU * 10 / PRECNT / 17600 - 1,  F_CPU * 10 / PRECNT / 18647 - 1,  F_CPU * 10 / PRECNT / 19755 - 1,  // gis"  a"  ais"  h"  (56-59)
  F_CPU * 10 / PRECNT / 20930 - 1,  F_CPU * 10 / PRECNT / 22175 - 1,  F_CPU * 10 / PRECNT / 23493 - 1,  F_CPU * 10 / PRECNT / 24890 - 1,  // c'" cis'" d'" dis'" (60-63)
  F_CPU * 10 / PRECNT / 26370 - 1,  F_CPU * 10 / PRECNT / 27938 - 1,  F_CPU * 10 / PRECNT / 29600 - 1,  F_CPU * 10 / PRECNT / 31360 - 1,  // e'" f'" fis'" g'"   (64-67)
  F_CPU * 10 / PRECNT / 33224 - 1,  F_CPU * 10 / PRECNT / 35200 - 1,  F_CPU * 10 / PRECNT / 37293 - 1,  F_CPU * 10 / PRECNT / 39511 - 1,  // gis'" a'" ais'" h'" (68-71)
  F_CPU * 10 / PRECNT / 41860 - 1                                                                                                         // c""                 (72)
};

// Notenlisten, eine Liste besteht aus Gruppen von 3 Bytes, die folgende Bedeutung haben:
// Byte 0: Tonhhe als Notenwert 0-72, 255 = Ende
// Byte 1: Tonlnge in 20ms-Einheiten
// Byte 2: Release-Wert in 20ms-Einheiten, alle 20ms wird der Lautstrkewert um den Release-Wert vermindert

// Weck-Ton 0: Buzzer 1 (3 kurze Signaltne)

const char sound00[] PROGMEM =
{
  50, 4, 0,       50, 4, 15,      50, 4, 0,       50, 4, 15,      50, 4, 0,       50, 29, 15,     255
};

// Weck-Ton 1: Buzzer 2 (4 kurze Signaltne)

const char sound01[] PROGMEM =
{
  50, 4, 0,       50, 4, 15,      50, 4, 0,       50, 4, 15,      50, 4, 0,       50, 4, 15,      50, 4, 0,       50, 21, 15,     255
};

// Weck-Ton 2: Buzzer 3 (2 lange Signaltne)

const char sound02[] PROGMEM =
{
  50, 13, 0,      50, 13, 20,      50, 13, 0,     50, 60, 20,     255
};

// Weck-Ton 3: Gong

const char sound03[] PROGMEM =
{
  45, 34, 1,      42, 101, 1,     255
};

// Weck-Ton 4: Unheimliche Begegnung der dritten Art (Close Encounters of the Third Kind)

const char sound04[] PROGMEM =
{
  46, 20, 2,      48, 20, 2,      44, 25, 2,      32, 30, 2,      39, 200, 1,     255
};

// Weck-Ton 5: Westminster (Big Ben)

const char sound05[] PROGMEM =
{
  28, 36, 1,      32, 36, 1,      30, 36, 1,      23, 108, 1,     28, 36, 1,      30, 36, 1,      32, 36, 1,      28, 108, 1,     32, 36, 1,      28, 36, 1,      30, 36, 1,      23, 108, 1,
  23, 36, 1,      30, 36, 1,      32, 36, 1,      28, 107, 1,     255
};

// Weck-Ton 6: Axel F. (Harold Faltermeyer)

const char sound06[] PROGMEM =
{
  29, 28, 3,      32, 21, 3,      29, 14, 3,      29, 7, 3,       34, 14, 3,      29, 14, 3,      27, 14, 3,      29, 28, 3,      36, 21, 3,      29, 14, 3,      29, 7, 3,       37, 14, 3,
  36, 14, 3,      32, 14, 3,      29, 14, 3,      36, 14, 3,      41, 14, 3,      29, 7, 3,       27, 14, 3,      27, 7, 3,       24, 14, 3,      31, 14, 3,      29, 125, 3,     255
};

// Weck-Ton 7: Blue Peter (Mike Oldfield)

const char sound07[] PROGMEM =
{
  36, 8, 5,       38, 8, 5,       41, 16, 5,      41, 16, 2,      41, 8, 5,       43, 8, 5,       45, 8, 5,       46, 8, 5,       48, 16, 5,      48, 16, 5,      48, 16, 2,      50, 8, 5,
  52, 8, 5,       53, 8, 5,       55, 8, 5,       53, 8, 5,       50, 8, 5,       48, 8, 5,       50, 8, 5,       48, 8, 5,       45, 8, 5,       43, 8, 5,       41, 8, 5,       38, 8, 5,
  41, 8, 5,       43, 16, 2,      36, 8, 5,       38, 8, 5,       41, 16, 5,      41, 16, 2,      41, 8, 5,       43, 8, 5,       45, 8, 5,       46, 8, 5,       48, 16, 5,      48, 16, 5,
  48, 16, 2,      53, 8, 5,       50, 8, 5,       52, 8, 5,       55, 8, 5,       52, 8, 5,       48, 8, 5,       45, 8, 5,       50, 8, 5,       47, 8, 5,       43, 8, 5,       48, 8, 5,
  47, 8, 5,       48, 8, 5,       47, 8, 5,       48, 16, 2,      36, 8, 5,       38, 8, 5,       41, 16, 5,      41, 16, 2,      41, 8, 5,       43, 8, 5,       45, 8, 5,       46, 8, 5,
  48, 16, 5,      48, 16, 5,      48, 16, 2,      50, 8, 5,       52, 8, 5,       53, 8, 5,       55, 8, 5,       53, 8, 5,       50, 8, 5,       48, 8, 5,       50, 8, 5,       48, 8, 5,
  45, 8, 5,       43, 8, 5,       41, 8, 5,       38, 8, 5,       41, 8, 5,       43, 16, 2,      36, 8, 5,       38, 8, 5,       41, 8, 5,       43, 8, 5,       41, 8, 5,       43, 8, 5,
  41, 8, 5,       50, 8, 5,       48, 8, 5,       45, 8, 5,       45, 8, 5,       43, 8, 5,       43, 8, 5,       45, 8, 5,       41, 16, 2,      50, 16, 2,      48, 8, 5,       50, 8, 5,
  48, 8, 5,       45, 8, 5,       41, 8, 5,       43, 8, 5,       45, 8, 5,       46, 8, 5,       48, 16, 5,      43, 2, 5,       45, 14, 5,      41, 15, 2,      255
};

// Weck-Ton 8: Around The World (ATC)

const char sound08[] PROGMEM =
{
  52, 11, 2,      45, 11, 2,      48, 11, 2,      52, 11, 2,      47, 11, 2,      40, 11, 2,      43, 11, 2,      47, 11, 2,      48, 11, 2,      41, 11, 2,      45, 11, 2,      48, 11, 2,
  50, 11, 2,      43, 11, 2,      47, 11, 2,      50, 10, 2,      255
};

// Weck-Ton 9: Fr Elise (Ludwig van Beethoven)

const char sound09[] PROGMEM =
{
  40, 10, 2,      39, 10, 2,      40, 10, 2,      39, 10, 2,      40, 10, 2,      35, 10, 2,      38, 10, 2,      36, 10, 2,      33, 30, 2,      24, 10, 2,      28, 10, 2,      33, 10, 2,
  35, 30, 2,      28, 10, 2,      32, 10, 2,      35, 10, 2,      36, 30, 2,      28, 10, 2,      40, 10, 2,      39, 10, 2,      40, 10, 2,      39, 10, 2,      40, 10, 2,      35, 10, 2,
  38, 10, 2,      36, 10, 2,      33, 30, 2,      24, 10, 2,      28, 10, 2,      33, 10, 2,      35, 30, 2,      28, 10, 2,      36, 10, 2,      35, 10, 2,      33, 39, 2,      255
};

// Pointerliste erstellen -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------

PGM_P const sounds[] PROGMEM =
{
   sound00, sound01, sound02, sound03, sound04, sound05, sound06, sound07, sound08, sound09
};

#endif /* SOUND_H_ */
